@@ -19,7 +19,7 @@ use Encode 'encode', 'decode';
 
 use Carp 'confess';
 
-our $VERSION = '0.0709';
+our $VERSION = '0.0710';
 
 my $SPVM_INITED;
 my $BUILDER;
@@ -40,15 +40,24 @@ sub import {
   # Add package informations
   if (defined $package_name) {
     my ($file, $line) = (caller)[1, 2];
-    $BUILDER->use($package_name, $file, $line);
     
-    $BUILDER->build_spvm;
-    unless ($BUILDER->compile_success) {
+    # Compile SPVM source code and create runtime env
+    my $compile_success = $BUILDER->compile_spvm($package_name, $file, $line);
+    unless ($compile_success) {
       exit(255);
     }
+    if ($compile_success) {
+      my $added_package_names = $BUILDER->get_added_package_names;
+      
+      # Build Precompile packages - Compile C source codes and link them to SPVM precompile subroutine
+      $BUILDER->build_precompile($added_package_names);
 
-    # Bind SPVM subroutine to Perl
-    bind_to_perl($BUILDER);
+      # Build native packages - Compile C source codes and link them to SPVM native subroutine
+      $BUILDER->build_native($added_package_names);
+
+      # Bind SPVM subroutine to Perl
+      bind_to_perl($BUILDER, $added_package_names);
+    }
   }
 }
 
@@ -65,50 +74,46 @@ sub init {
 my $package_name_h = {};
 my $binded_package_name_h = {};
 sub bind_to_perl {
-  my $builder = shift;
+  my ($builder, $added_package_names) = @_;
   
-  my $package_names = $builder->get_package_names;
-  for my $package_name (@$package_names) {
-    unless ($binded_package_name_h->{$package_name}) {
-      my $sub_names = $builder->get_sub_names($package_name);
-      
-      for my $sub_name (@$sub_names) {
-        if ($sub_name eq 'DESTROY') {
-          next;
-        }
-        
-        my $sub_abs_name = "${package_name}::$sub_name";
-        
-        # Define SPVM subroutine
-        no strict 'refs';
-        
-        my ($package_name, $sub_name) = $sub_abs_name =~ /^(?:(.+)::)(.*)/;
-        unless ($package_name_h->{$package_name}) {
-          
-          my $code = "package $package_name; our \@ISA = ('SPVM::BlessedObject::Package');";
-          eval $code;
-          
-          if (my $error = $@) {
-            confess $error;
-          }
-          $package_name_h->{$package_name} = 1;
-        }
-        
-        # Declare subroutine
-        *{"$sub_abs_name"} = sub {
-          SPVM::init() unless $SPVM_INITED;
-          
-          my $return_value;
-          eval { $return_value = SPVM::call_sub($package_name, $sub_name, @_) };
-          my $error = $@;
-          if ($error) {
-            confess $error;
-          }
-          $return_value;
-        };
+  for my $package_name (@$added_package_names) {
+    my $sub_names = $builder->get_sub_names($package_name);
+    
+    for my $sub_name (@$sub_names) {
+      if ($sub_name eq 'DESTROY') {
+        next;
       }
+      
+      my $sub_abs_name = "${package_name}::$sub_name";
+      
+      # Define SPVM subroutine
+      no strict 'refs';
+      
+      my ($package_name, $sub_name) = $sub_abs_name =~ /^(?:(.+)::)(.*)/;
+      unless ($package_name_h->{$package_name}) {
+        
+        my $code = "package $package_name; our \@ISA = ('SPVM::BlessedObject::Package');";
+        eval $code;
+        
+        if (my $error = $@) {
+          confess $error;
+        }
+        $package_name_h->{$package_name} = 1;
+      }
+      
+      # Declare subroutine
+      *{"$sub_abs_name"} = sub {
+        SPVM::init() unless $SPVM_INITED;
+        
+        my $return_value;
+        eval { $return_value = SPVM::call_sub($package_name, $sub_name, @_) };
+        my $error = $@;
+        if ($error) {
+          confess $error;
+        }
+        $return_value;
+      };
     }
-    $binded_package_name_h->{$package_name} = 1;
   }
 }
 
